==> gnomeicu-0.65.tar.gz: gnomeicu-0.65/src/rus_conv.c <==
/*
 * Russian Language fix
 *
 * Usual Windows ICQ users use Windows 1251 encoding.
 * UNIX users use KOI8 encoding.
 *
 * Original Author: Andrew Frolov (dron@ilm.net)
 */

#include "gnomeicu.h"
#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>

typedef unsigned char uchar;

uchar kw[] = { 128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,
               144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,
               160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,
               176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,
               254,224,225,246,228,229,244,227,245,232,233,234,235,236,237,238,
               239,255,240,241,242,243,230,226,252,251,231,248,253,249,247,250,
               222,192,193,214,196,197,212,195,213,200,201,202,203,204,205,206,
               207,223,208,209,210,211,198,194,220,219,199,216,221,217,215,218 };

uchar wk[] = { 128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,
               144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,
               160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,
               176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,
               225,226,247,231,228,229,246,250,233,234,235,236,237,238,239,240,
               242,243,244,245,230,232,227,254,251,253,255,249,248,252,224,241,
               193,194,215,199,196,197,214,218,201,202,203,204,205,206,207,208,
               210,211,212,213,198,200,195,222,219,221,223,217,216,220,192,209 };

void rus_conv( short to, char *t_in )
{
	static uchar *table = NULL;

	switch( to )
	{
		case RUS_WIN_KOI:
			table = wk;
			break;
		case RUS_KOI_WIN:
			table = kw;
			break;
		default:
			g_print( "Error - unknown encoding\n" );
			return;
	}

	if ( Russian )
	{
		int i;
		for( i = 0; t_in[ i ] != '\0'; i++ )
		{
			t_in[ i ] &= 255;
			
			if(t_in[ i ] & 128)
			{
				t_in[ i ] = table[ t_in[ i ] & 127 ];
			}
		}
	}
}

==> gnomeicu-0.96.tar.gz: gnomeicu-0.96/src/rus_conv.c <==
/*************************
 Russian conversions
 (c) 1999 Jeremy Wise
 GnomeICU
**************************/

/*** GnomeICU header files ***/
#include "common.h"
   
/*** Toplevel header files ***/
#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>


typedef guchar uchar;

uchar kw[] = { 128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,
               144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,
               160,161,162,184,186,165,179,191,168,169,170,171,172,180,174,175,
               176,177,178,168,170,181,178,175,184,185,186,187,188,165,190,169,
               254,224,225,246,228,229,244,227,245,232,233,234,235,236,237,238,
               239,255,240,241,242,243,230,226,252,251,231,248,253,249,247,250,
               222,192,193,214,196,197,212,195,213,200,201,202,203,204,205,206,
               207,223,208,209,210,211,198,194,220,219,199,216,221,217,215,218 };

uchar wk[] = { 128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,
               144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,
               160,161,162,180,164,189,166,167,179,191,170,171,172,173,174,183,
               176,177,182,166,180,181,182,183,163,185,186,187,164,173,190,167,
               225,226,247,231,228,229,246,250,233,234,235,236,237,238,239,240,
               242,243,244,245,230,232,227,254,251,253,255,249,248,252,224,241,
               193,194,215,199,196,197,214,218,201,202,203,204,205,206,207,208,
               210,211,212,213,198,200,195,222,219,221,223,217,216,220,192,209 };

/*** Global functions ***/
void rus_conv( short to, char *t_in )
{
	static uchar *table = NULL;
	int i;

/*	if ( Russian ) */
	if ( toggles->russian == FALSE )
		return;

	switch( to )
	{
		case RUS_WIN_KOI:
			table = wk;
			break;
		case RUS_KOI_WIN:
			table = kw;
			break;
		default:
			g_print( "Error - unknown encoding\n" );
			return;
	}

	for( i = 0; t_in[ i ] != '\0'; i++ )
	{
		t_in[ i ] &= 255;
		
		if(t_in[ i ] & 128)
		{
			t_in[ i ] = table[ t_in[ i ] & 127 ];
		}
	}
}
